@@ -14,7 +14,6 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import six
 
 from oslo_serialization import jsonutils
 from oslo_utils import uuidutils
@@ -29,11 +28,11 @@ class Execution(base.Resource):
 class ExecutionManager(base.ResourceManager):
     resource_class = Execution
 
-    def create(self, workflow_identifier='', namespace='',
+    def create(self, wf_identifier='', namespace='',
                workflow_input=None, description='', source_execution_id=None,
                **params):
         self._ensure_not_empty(
-            workflow_identifier=workflow_identifier or source_execution_id
+            workflow_identifier=wf_identifier or source_execution_id
         )
 
         data = {'description': description}
@@ -41,17 +40,17 @@ class ExecutionManager(base.ResourceManager):
         if uuidutils.is_uuid_like(source_execution_id):
             data.update({'source_execution_id': source_execution_id})
 
-        if workflow_identifier:
-            if uuidutils.is_uuid_like(workflow_identifier):
-                data.update({'workflow_id': workflow_identifier})
+        if wf_identifier:
+            if uuidutils.is_uuid_like(wf_identifier):
+                data.update({'workflow_id': wf_identifier})
             else:
-                data.update({'workflow_name': workflow_identifier})
+                data.update({'workflow_name': wf_identifier})
 
         if namespace:
             data.update({'workflow_namespace': namespace})
 
         if workflow_input:
-            if isinstance(workflow_input, six.string_types):
+            if isinstance(workflow_input, str):
                 data.update({'input': workflow_input})
             else:
                 data.update({'input': jsonutils.dumps(workflow_input)})
@@ -80,6 +79,10 @@ class ExecutionManager(base.ResourceManager):
         if task:
             filters['task_execution_id'] = task
 
+        # for backwards compatibility
+        if 'nulls' in filters and not filters['nulls']:
+            filters.pop('nulls')
+
         query_string = self._build_query_params(
             marker=marker,
             limit=limit,
@@ -120,7 +123,8 @@ class ExecutionManager(base.ResourceManager):
 
         self._delete('/executions/%s%s' % (id, query_string))
 
-    def get_report(self, id, errors_only=True, max_depth=None):
+    def get_report(self, id, errors_only=True, max_depth=None,
+                   statistics_only=False):
         self._ensure_not_empty(id=id)
 
         query_params = {}
@@ -128,6 +132,9 @@ class ExecutionManager(base.ResourceManager):
         if errors_only:
             query_params['errors_only'] = True
 
+        if statistics_only:
+            query_params['statistics_only'] = True
+
         if max_depth is not None:
             query_params['max_depth'] = max_depth
 
